import { Material, Object3D, Texture } from "three";
import { CompilerManager } from "../manager/CompilerManager";
import { DataSupportManager, DataSupportManagerParameters, LoadOptions } from "../manager/DataSupportManager";
import { LoaderManager } from "../manager/LoaderManager";
import { RenderManager } from "../manager/RenderManager";
import { MappedEvent, ResourceManager } from "../manager/ResourceManager";
import { SymbolConfig } from "../middleware/common/CommonConfig";
import { Engine } from "./Engine";
export declare type EngineSupportParameters = DataSupportManagerParameters;
export interface EngineSupportLoadOptions extends LoadOptions {
    assets?: string[];
}
export declare class EngineSupport extends Engine {
    IS_ENGINESUPPORT: boolean;
    loaderManager: LoaderManager;
    resourceManager: ResourceManager;
    dataSupportManager: DataSupportManager;
    compilerManager: CompilerManager;
    renderManager: RenderManager;
    loadResources: (urlList: Array<string>) => this;
    registerResources: (resourceMap: {
        [key: string]: unknown;
    }) => this;
    loadResourcesAsync: (urlList: Array<string>) => Promise<MappedEvent>;
    toJSON: () => string;
    exportConfig: (compress: boolean) => LoadOptions;
    applyConfig: <T extends SymbolConfig>(...configs: T[]) => this;
    reactiveConfig: <T extends SymbolConfig>(config: T) => T;
    getConfigBySymbol: <T extends SymbolConfig>(vid: string) => T | null;
    removeConfigBySymbol: (vid: string) => this;
    getObjectSymbol: (object: any) => SymbolConfig["vid"] | null;
    getObjectBySymbol: (vid: string) => Object3D | Texture | Material | null;
    constructor(parameters?: EngineSupportParameters, resources?: {
        [key: string]: any;
    });
    private loadLifeCycle;
    private removeLifeCycle;
    loadConfig(config: EngineSupportLoadOptions, callback?: (event?: MappedEvent) => void): this;
    loadConfigAsync(config: EngineSupportLoadOptions): Promise<MappedEvent | undefined>;
    removeConfig(config: EngineSupportLoadOptions): void;
    getObjectConfig<O, C extends SymbolConfig>(object: O): C | null;
}
